# Cromwell Files

This directory contains the files to build Lapdog's wdl_runner Docker image

These files came from the [OpenWDL](https://github.com/openwdl/wdl) repository and are
licensed under the BSD-3 license (a copy of which is included in this directory).

These files were cloned from [48f9aca](https://github.com/openwdl/wdl/tree/48f9aca78cd12479f49cd1c8290ef4dae4e17a19)
and have been modified to suit the needs of Lapdog
